@@ -4,7 +4,8 @@ import re
 import logging
 import requests
 
-from ..backends import detect_backend, VideoBackend
+from ..backends import detect_backend, VideoBackend, \
+    VideoDoesntExistException, UnknownBackendException
 
 register = Library()
 
@@ -37,6 +38,7 @@ class VideoNode(Node):
 
         {% video item.video "large" %}
         {% video item.video "340x200" %}
+        {% video item.video "100% x 300" %}
 
         {% video item.video as my_video %}
             URL: {{ my_video.url }}
@@ -48,7 +50,7 @@ class VideoNode(Node):
     error_msg = 'Syntax error. Expected: ``{% video URL ... %}``'
     default_size = 'small'
 
-    re_size = re.compile('(?P<width>\d+)x(?P<height>\d+)')
+    re_size = re.compile('(?P<width>\d+%?) *x *(?P<height>\d+%?)')
 
     def __init__(self, parser, token):
         self.size = None
@@ -71,15 +73,19 @@ class VideoNode(Node):
     def render(self, context):
         url = self.url.resolve(context)
 
-        # Fixes #18. If no video url is provided it should return an empty
-        # string instead raising UnknownBackendException.
-        if not url:
-            return ''
+        try:
+            if self.size:
+                return self.__render_embed(url, context)
+            else:
+                return self.__render_block(url, context)
+        except requests.Timeout:
+            logger.exception('Timeout reached during rendering embed video (`{0}`)'.format(url))
+        except UnknownBackendException:
+            logger.exception('Backend wasn\'t recognised (`{0}`)'.format(url))
+        except VideoDoesntExistException:
+            logger.exception('Attempt to render not existing video (`{0}`)'.format(url))
 
-        if self.size:
-            return self.__render_embed(url, context)
-        else:
-            return self.__render_block(url, context)
+        return ''
 
     def __render_embed(self, url, context):
         size = self.size.resolve(context) \
@@ -87,24 +93,27 @@ class VideoNode(Node):
         return self.embed(url, size, context=context)
 
     def __render_block(self, url, context):
-        output = ''
         as_var = self.bits[-1]
 
-        try:
-            context.push()
-            context[as_var] = self.get_backend(url, context=context)
-            output = self.nodelist_file.render(context)
-            context.pop()
-        except requests.Timeout:
-            logger.exception('Timeout reached during rendering embed '
-                             'video (`{0}`)'.format(url))
+        context.push()
+        context[as_var] = self.get_backend(url, context=context)
+        output = self.nodelist_file.render(context)
+        context.pop()
 
         return output
 
     @staticmethod
-    def get_backend(backend, context=None):
-        if not isinstance(backend, VideoBackend):
-            backend = detect_backend(backend)
+    def get_backend(backend_or_url, context=None):
+        """
+        Returns instance of VideoBackend. If context is passed to the method
+        and request is secure, than the is_secure mark is set to backend.
+        
+        A string or VideoBackend instance can be passed to the method.
+        """
+        
+        backend = backend_or_url if isinstance(backend_or_url, VideoBackend) \
+                    else detect_backend(backend_or_url)
+                    
         if context and 'request' in context:
             backend.is_secure = context['request'].is_secure()
 
@@ -150,7 +159,7 @@ class VideoNode(Node):
 
         try:
             size = VideoNode.re_size.match(value)
-            return [int(size.group('width')), int(size.group('height'))]
+            return [size.group('width'), size.group('height')]
         except AttributeError:
             raise TemplateSyntaxError(
                 'Incorrect size.\nPossible format is WIDTHxHEIGHT or using '
@@ -172,7 +181,7 @@ def embed(backend, size='small'):
         .. deprecated:: 0.7
             Use :py:func:`VideoNode.embed` instead.
 
-    Same like :py:func:`VideoNode.embed` tag but **always uses in secure
+    Same like :py:func:`VideoNode.embed` tag but **always uses insecure
     HTTP protocol**.
 
     Usage:
