@@ -7,5 +7,5 @@ class CustomBackend(VideoBackend):
     re_detect = re.compile(r'http://myvideo\.com/[0-9]+')
     re_code = re.compile(r'http://myvideo\.com/(?P<code>[0-9]+)')
 
-    pattern_url = 'http://play.myvideo.com/c/%s/'
-    pattern_thumbnail_url = 'http://thumb.myvideo.com/c/%s/'
+    pattern_url = '{protocol}://play.myvideo.com/c/{code}/'
+    pattern_thumbnail_url = '{protocol}://thumb.myvideo.com/c/{code}/'
