@@ -27,7 +27,8 @@ class EmbedVideoNodeTestCase(TestCase):
                 {% video ytb 'large' %}
             {% endvideo %}
         """)
-        rendered = u'<iframe width="960" height="720" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque" frameborder="0" allowfullscreen></iframe>'
+        rendered = u'''<iframe width="960" height="720" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque"
+        frameborder="0" allowfullscreen></iframe>'''
         self.assertEqual(template.render(self._grc()).strip(), rendered)
 
     def test_direct_embed(self):
@@ -35,7 +36,8 @@ class EmbedVideoNodeTestCase(TestCase):
             {% load embed_video_tags %}
             {{ 'http://www.youtube.com/watch?v=jsrRJyHBvzw'|embed:'large' }}
         """)
-        rendered = u'<iframe width="960" height="720" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque" frameborder="0" allowfullscreen></iframe>'
+        rendered = u'''<iframe width="960" height="720" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque"
+        frameborder="0" allowfullscreen></iframe>'''
         self.assertEqual(template.render(self._grc()).strip(), rendered)
 
     def test_direct_embed_tag(self):
@@ -43,7 +45,8 @@ class EmbedVideoNodeTestCase(TestCase):
             {% load embed_video_tags %}
             {% video "http://www.youtube.com/watch?v=jsrRJyHBvzw" "large" %}
         """)
-        rendered = u'<iframe width="960" height="720" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque" frameborder="0" allowfullscreen></iframe>'
+        rendered = u'''<iframe width="960" height="720" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque"
+        frameborder="0" allowfullscreen></iframe>'''
         self.assertEqual(template.render(self._grc()).strip(), rendered)
 
     def test_direct_embed_tag_with_default_size(self):
@@ -51,7 +54,8 @@ class EmbedVideoNodeTestCase(TestCase):
             {% load embed_video_tags %}
             {% video "http://www.youtube.com/watch?v=jsrRJyHBvzw" %}
         """)
-        rendered = u'<iframe width="480" height="360" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque" frameborder="0" allowfullscreen></iframe>'
+        rendered = u'''<iframe width="480" height="360" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque"
+        frameborder="0" allowfullscreen></iframe>'''
         self.assertEqual(template.render(self._grc()).strip(), rendered)
 
     def test_user_size(self):
@@ -61,7 +65,8 @@ class EmbedVideoNodeTestCase(TestCase):
                 {% video ytb '800x800' %}
             {% endvideo %}
         """)
-        rendered = u'<iframe width="800" height="800" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque" frameborder="0" allowfullscreen></iframe>'
+        rendered = u'''<iframe width="800" height="800" src="http://www.youtube.com/embed/jsrRJyHBvzw?wmode=opaque"
+        frameborder="0" allowfullscreen></iframe>'''
         self.assertEqual(template.render(self._grc()).strip(), rendered)
 
     def test_wrong_size(self):
@@ -182,3 +187,28 @@ class EmbedVideoNodeTestCase(TestCase):
             log = logs.records[-1]
             self.assertEqual(log.name, 'embed_video.templatetags.embed_video_tags')
             self.assertEqual(log.msg, 'Timeout reached during rendering embed video (`http://vimeo.com/72304002`)')
+
+    def test_relative_size(self):
+        template = Template("""
+            {% load embed_video_tags %}
+            {% video "http://vimeo.com/72304002" "80%x30%" %}
+        """)
+        rendered = '<iframe width="80%" height="30%" src="http://player.vimeo.com/video/72304002"' \
+                   '\n        frameborder="0" allowfullscreen></iframe>'
+        self.assertEqual(template.render(self._grc()).strip(), rendered)
+
+    def test_allow_spaces_in_size(self):
+        template = Template("""
+            {% load embed_video_tags %}
+            {% video "http://vimeo.com/72304002" "80% x 300" %}
+        """)
+        rendered = '<iframe width="80%" height="300" src="http://player.vimeo.com/video/72304002"' \
+                   '\n        frameborder="0" allowfullscreen></iframe>'
+        self.assertEqual(template.render(self._grc()).strip(), rendered)
+
+    def test_soundcloud_invalid_url(self):
+        template = Template("""
+            {% load embed_video_tags %}
+            {% video "https://soundcloud.com/xyz/foo" %}
+        """)
+        self.assertEqual(template.render(self._grc()).strip(), '')
